@@ -28,6 +28,10 @@
  * Boston, MA 02111-1307, USA.
  */
 
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
 #include "eog-image-jpeg.h"
 
 #if HAVE_JPEG
@@ -43,13 +47,19 @@
 #include <transupp.h>
 #include <glib.h>
 #include <gdk-pixbuf/gdk-pixbuf.h>
-#include <libgnome/gnome-i18n.h>
+#include <glib/gi18n.h>
 #include <libgnomevfs/gnome-vfs.h>
 #if HAVE_EXIF
 #include <libexif/exif-data.h>
 #endif
 #include "eog-image-private.h"
 
+#ifdef G_OS_WIN32
+#define sigjmp_buf jmp_buf
+#define sigsetjmp(env, savesigs) setjmp (env)
+#define siglongjmp longjmp
+#endif
+
 typedef enum {
 	EOG_SAVE_NONE,
 	EOG_SAVE_JPEG_AS_JPEG,
@@ -87,7 +97,7 @@ fatal_error_handler (j_common_ptr cinfo)
 			     g_path_get_basename (errmgr->filename),
                              buffer);
         }
-        
+
 	siglongjmp (errmgr->setjmp_buffer, 1);
 
         g_assert_not_reached ();
