@@ -111,6 +111,11 @@ eog_image_dispose (GObject *object)
 		priv->file_type = NULL;
 	}
 	
+	if (priv->error_message) {
+		g_free (priv->error_message);
+		priv->error_message = NULL;
+	}
+	
 	if (priv->status_mutex) {
 		g_mutex_free (priv->status_mutex);
 		priv->status_mutex = NULL;
@@ -263,6 +268,7 @@ eog_image_instance_init (EogImage *img)
 	priv->modified = FALSE;
 	priv->status_mutex = g_mutex_new ();
 	priv->load_finished = NULL;
+	priv->error_message = NULL;
 #if HAVE_EXIF
 	priv->exif = NULL;
 #endif
@@ -449,7 +455,8 @@ eog_image_determine_file_bytes (EogImage *img, GError **error)
 	info = gnome_vfs_file_info_new ();
 	result = gnome_vfs_get_file_info_uri (img->priv->uri,
 					      info,
-					      GNOME_VFS_FILE_INFO_DEFAULT);
+					      GNOME_VFS_FILE_INFO_DEFAULT |
+					      GNOME_VFS_FILE_INFO_FOLLOW_LINKS);
 
 	if ((result != GNOME_VFS_OK) || (info->valid_fields & GNOME_VFS_FILE_INFO_FIELDS_SIZE) == 0) {
 		bytes = 0;
@@ -797,6 +804,11 @@ eog_image_real_load (EogImage *img, guint data2read, EogJob *job, GError **error
 	
 	failed = (failed || bytes_read_total == 0 || priv->cancel_loading);
 
+	if (*error != NULL) {
+		failed = TRUE;
+		priv->status = EOG_IMAGE_STATUS_FAILED;
+	}
+
 	if (priv->cancel_loading) {
 		priv->cancel_loading = FALSE;
 		failed = TRUE;
@@ -908,6 +920,8 @@ eog_image_load (EogImage *img, guint data2read, EogJob *job, GError **error)
 	}
 
 	if (priv->status == EOG_IMAGE_STATUS_FAILED) {
+		g_set_error (error, EOG_IMAGE_ERROR, EOG_IMAGE_ERROR_NOT_LOADED, 
+			     priv->error_message);
 		return FALSE;
 	}
 	
@@ -946,6 +960,12 @@ eog_image_load (EogImage *img, guint data2read, EogJob *job, GError **error)
 	}
 	else {
 		priv->status = EOG_IMAGE_STATUS_FAILED;
+
+		/* set the image error message */
+		if (priv->error_message != NULL) {
+			g_free (priv->error_message);
+		}
+		priv->error_message = g_strdup((*error)->message);
 	}
 
 	return success;
@@ -1960,8 +1980,8 @@ eog_image_print (EogImage *img, GnomePrintContext *context, gdouble paper_width,
 	pix_width = gdk_pixbuf_get_width (printed_image);
 	pix_height = gdk_pixbuf_get_height (printed_image);
 
-	width = (gint)paper_width - 40; /* - 2 * gnome_paper_tmargin (paper); */
-	height = (gint)paper_height - 40; /* - 2 * gnome_paper_rmargin (paper); */
+	width = (gint)paper_width;
+	height = (gint)paper_height;
 
 	if (((gdouble) pix_height/pix_width) >
 	    ((gdouble)width/height)) {
@@ -1972,6 +1992,9 @@ eog_image_print (EogImage *img, GnomePrintContext *context, gdouble paper_width,
 		height = width * (gdouble)pix_height/pix_width;
 	}
 
+	width -= 40;
+	height -= 40;
+	
 	gnome_print_translate (context, (paper_width - width)/2.0, (paper_height - height)/2.0);
 	gnome_print_scale (context, width, height);
 	
